@@ -43,19 +43,23 @@ static void getKDE(FFstrbuf* result, FFDEOptions* options)
     }
 }
 
-static const char* getGnomeBySo(FFstrbuf* result)
+static const char* getGnomeByDbus(FF_MAYBE_UNUSED FFstrbuf* result)
 {
+#ifdef FF_HAVE_DBUS
     FFDBusData dbus;
     if (ffDBusLoadData(DBUS_BUS_SESSION, &dbus) != NULL)
         return "ffDBusLoadData() failed";
 
     ffDBusGetPropertyString(&dbus, "org.gnome.Shell", "/org/gnome/Shell", "org.gnome.Shell", "ShellVersion", result);
     return NULL;
+#else // FF_HAVE_DBUS
+    return "ffDBusLoadData() failed: dbus support not compiled in";
+#endif // FF_HAVE_DBUS
 }
 
 static void getGnome(FFstrbuf* result, FF_MAYBE_UNUSED FFDEOptions* options)
 {
-    getGnomeBySo(result);
+    getGnomeByDbus(result);
 
     if (result->length == 0 && options->slowVersionDetection)
     {
