@@ -84,9 +84,10 @@ static bool printImageIterm(bool printError)
             ffStrbufAppendNC(&buf, options->paddingTop, '\n');
             ffStrbufAppendNC(&buf, options->paddingLeft, ' ');
         }
-        ffStrbufAppendF(&buf, "\e]1337;File=inline=1:%s\a",
-            base64.chars
-        );
+        if (options->width)
+            ffStrbufAppendF(&buf, "\e]1337;File=inline=1;width=%u:%s\a", (unsigned) options->width, base64.chars);
+        else
+            ffStrbufAppendF(&buf, "\e]1337;File=inline=1:%s\a", base64.chars);
         ffWriteFDBuffer(FFUnixFD2NativeFD(STDOUT_FILENO), &buf);
 
         if (!options->separate)
@@ -164,7 +165,11 @@ static bool printImageKittyDirect(bool printError)
             ffPrintCharTimes('\n', options->paddingTop);
             ffPrintCharTimes(' ', options->paddingLeft);
         }
-        printf("\e_Ga=T,f=100,t=f;%s\e\\", base64.chars);
+
+        if (options->width)
+            printf("\e_Ga=T,f=100,t=f,c=%u;%s\e\\", (unsigned) options->width, base64.chars);
+        else
+            printf("\e_Ga=T,f=100,t=f;%s\e\\", base64.chars);
         fflush(stdout);
         if (!options->separate)
         {
@@ -781,7 +786,7 @@ static bool printImageIfExistsSlowPath(FFLogoType type, bool printError)
     if(!getCharacterPixelDimensions(&requestData))
     {
         if(printError)
-            fputs("Logo: getCharacterPixelDimensions() failed", stderr);
+            fputs("Logo: getCharacterPixelDimensions() failed\n", stderr);
         return false;
     }
 
@@ -798,7 +803,7 @@ static bool printImageIfExistsSlowPath(FFLogoType type, bool printError)
         //We can safely return here, because if realpath failed, we surely won't be able to read the file
         ffStrbufDestroy(&requestData.cacheDir);
         if(printError)
-            fputs("Logo: Querying realpath of the image source failed", stderr);
+            fputs("Logo: Querying realpath of the image source failed\n", stderr);
         return false;
     }
     ffStrbufRecalculateLength(&requestData.cacheDir);
@@ -842,6 +847,13 @@ static bool printImageIfExistsSlowPath(FFLogoType type, bool printError)
 
 bool ffLogoPrintImageIfExists(FFLogoType type, bool printError)
 {
+    if(instance.config.display.pipe)
+    {
+        if(printError)
+            fputs("Logo: Image logo is not supported in pipe mode\n", stderr);
+        return false;
+    }
+
     if(!ffPathExists(instance.config.logo.source.chars, FF_PATHTYPE_FILE))
     {
         if(printError)
@@ -849,22 +861,14 @@ bool ffLogoPrintImageIfExists(FFLogoType type, bool printError)
         return false;
     }
 
-    if (getenv("SSH_TTY"))
-    {
-        if(printError)
-            fputs("Logo: Image logo is not supported in SSH sessions\n", stderr);
-        return false;
-    }
-
     const char* term = getenv("TERM");
-    if((term && ffStrEquals(term, "screen")) || getenv("ZELLIJ") || getenv("TMUX"))
+    if((term && ffStrEquals(term, "screen")) || getenv("ZELLIJ"))
     {
         if(printError)
             fputs("Logo: Image logo is not supported in terminal multiplexers\n", stderr);
         return false;
     }
 
-
     if(type == FF_LOGO_TYPE_IMAGE_ITERM)
         return printImageIterm(printError);
 
