@@ -29,6 +29,7 @@ void ffOptionsInitModules(FFOptionsModules* options)
     ffInitIconsOptions(&options->icons);
     ffInitKernelOptions(&options->kernel);
     ffInitLMOptions(&options->lm);
+    ffInitLoadavgOptions(&options->loadavg);
     ffInitLocalIpOptions(&options->localIP);
     ffInitLocaleOptions(&options->locale);
     ffInitMediaOptions(&options->media);
@@ -40,6 +41,7 @@ void ffOptionsInitModules(FFOptionsModules* options)
     ffInitOpenGLOptions(&options->openGL);
     ffInitPackagesOptions(&options->packages);
     ffInitPhysicalDiskOptions(&options->physicalDisk);
+    ffInitPhysicalMemoryOptions(&options->physicalMemory);
     ffInitPlayerOptions(&options->player);
     ffInitPowerAdapterOptions(&options->powerAdapter);
     ffInitProcessesOptions(&options->processes);
@@ -93,6 +95,7 @@ void ffOptionsDestroyModules(FFOptionsModules* options)
     ffDestroyIconsOptions(&options->icons);
     ffDestroyKernelOptions(&options->kernel);
     ffDestroyLMOptions(&options->lm);
+    ffDestroyLoadavgOptions(&options->loadavg);
     ffDestroyLocalIpOptions(&options->localIP);
     ffDestroyLocaleOptions(&options->locale);
     ffDestroyMediaOptions(&options->media);
@@ -103,6 +106,7 @@ void ffOptionsDestroyModules(FFOptionsModules* options)
     ffDestroyOpenCLOptions(&options->openCL);
     ffDestroyOpenGLOptions(&options->openGL);
     ffDestroyPhysicalDiskOptions(&options->physicalDisk);
+    ffDestroyPhysicalMemoryOptions(&options->physicalMemory);
     ffDestroyPackagesOptions(&options->packages);
     ffDestroyPlayerOptions(&options->player);
     ffDestroyPowerAdapterOptions(&options->powerAdapter);
